#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xss-sanitize
version: 0.3.5.7
id: xss-sanitize-0.3.5.7-e5c809552f485f0cae8f01d1b991e326
key: xsssa_AUbijHu4zP0D8gM2KdDi0S
license: BSD2
maintainer: Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://github.com/yesodweb/haskell-xss-sanitize
synopsis: sanitize untrusted HTML to prevent XSS attacks
description:
    run untrusted HTML through Text.HTML.SanitizeXSS.sanitizeXSS to prevent XSS attacks. see README.md <http://github.com/yesodweb/haskell-xss-sanitize> for more details
category: Web
author: Greg Weber <greg@gregweber.info>
exposed: True
exposed-modules:
    Text.HTML.SanitizeXSS
hidden-modules: Text.HTML.SanitizeXSS.Css
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/xss-sanitize-0.3.5.7
library-dirs: /usr/lib/ghc-7.10.3/site-local/xss-sanitize-0.3.5.7
data-dir: /usr/share/arm-linux-ghc-7.10.3/xss-sanitize-0.3.5.7
hs-libraries: HSxss-sanitize-0.3.5.7-AUbijHu4zP0D8gM2KdDi0S
depends:
    attoparsec-0.13.0.2-669cbb29a91e49834657a781d3adc2de
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    css-text-0.1.2.1-fd7cfa8d457b06bb47b9d76e18d81e4c
    network-uri-2.6.1.0-522aa8cc2805dab5af7064f70c4a777d
    tagsoup-0.13.10-e0607642a7a600be1f9d9bab46fd617e
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    utf8-string-1.0.1.1-55be01444fdc59e978af349d80596373
haddock-interfaces: /usr/share/doc/haskell-xss-sanitize/html/xss-sanitize.haddock
haddock-html: /usr/share/doc/haskell-xss-sanitize/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
